a length one character vector. Starting point for babbling!
If NA, as by default, a random word is sampled from the model's
dictionary.
n_max
a length one integer. Maximum number of words to generate.
L
a length one integer. Number of next-word suggestions from
which to sample (see details).
Value
A character vector of length one.
Details
This function generates random text from a Stupid Back-off language
model.
babble randomly samples one of the top L next word
predictions. Text generation stops when an End-Of-Sentence token is
encountered, or when the number of generated words exceeds n_max.